; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10

;===============================================================================
; CPUASYpR}h
;===============================================================================

;AI-----------------------------------------------------------------------------
[Command]
name = "AI0"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI1"
command = b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b
time = 0
[Command]
name = "AI2"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI3"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI4"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI5"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI6"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI7"
command = F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F
time = 0
[Command]
name = "AI8"
command = D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D
time = 0
[Command]
name = "AI9"
command = B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B
time = 0
[Command]
name = "AI10"
command = U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U
time = 0
[Command]
name = "AI11"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI12"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI13"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI14"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI15"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI16"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI17"
command = a,B,c,x,y,z,s,B,D,F,U,a,b,c,x,y,z,s,s
time = 0
[Command]
name = "AI18"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI19"
command = b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b
time = 0
[Command]
name = "AI20"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI21"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI22"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI23"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI24"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI25"
command = F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F
time = 0
[Command]
name = "AI26"
command = D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D
time = 0
[Command]
name = "AI27"
command = B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B
time = 0
[Command]
name = "AI28"
command = U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U
time = 0
[Command]
name = "AI29"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI30"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI31"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI32"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI33"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI34"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI35"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI36"
command = z,z,z,z,z,z,a,a,a,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI37"
command = z,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,z,z,z
time = 0
[Command]
name = "AI38"
command = z,z,z,z,z,a,a,a,z,z,z,z,z,a,a,a,z,z,z
time = 0
[Command]
name = "AI39"
command = z,z,z,z,z,a,a,a,z,z,z,z,z,z,a,a,z,z,z
time = 0
[Command]
name = "AI40"
command = z,z,z,z,a,a,a,z,z,z,z,a,z,z,a,a,z,z,z
time = 0


[command]
name="fwd"
command=F
time=1
[command]
name="back"
command=B
time=1
[command]
name="up"
command=U
time=1
[command]
name="down"
command=D
time=1

;-| Button Remapping |----------------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |------------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "DP_z"
command = ~F, D, DF, z
time = 30

[Command]
name = "2QCB_z"
command = ~D, DB, B, D, DB, z
time = 30

[Command]
name = "2QCF_ab"
command = ~D, DF, F, D, DF, a+b
time = 30

[Command]
name = "2QCF_a"
command = ~D, DF, F, D, DF, a
time = 30

[Command]
name = "2QCF_b"
command = ~D, DF, F, D, DF, b
time = 30

[Command]
name = "2QCF_xy"
command = ~D, DF, F, D, DF, x+y
time = 30

[Command]
name = "2QCF_x"
command = ~D, DF, F, D, DF, x
time = 30

[Command]
name = "2QCF_y"
command = ~D, DF, F, D, DF, y
time = 30

[Command]
name = "QCBHCF_xy"
command = ~D, B, D, F, x+y
time = 30

[Command]
name = "QCBHCF_x"
command = ~D, B, D, F, x
time = 30

[Command]
name = "QCBHCF_y"
command = ~D, B, D, F, y
time = 30

[Command]
name = "QCFHCB_z"
command = ~D, F, D, B, z
time = 30

[Command]
name = "QCFHCB_xy"
command = ~D, F, D, B, x+y
time = 30

[Command]
name = "QCFHCB_x"
command = ~D, F, D, B, x
time = 30

[Command]
name = "QCFHCB_y"
command = ~D, F, D, B, y
time = 30

;-| Special Motions |------------------------------------------------------
[Command]
name = "DU_x"
command = ~10$D, $U, x
time = 20

[Command]
name = "DU_y"
command = ~10$D, $U, y
time = 20

[Command]
name = "RDP_x"
command = ~B, D, DB, x
time = 20

[Command]
name = "RDP_y"
command = ~B, D, DB, y
time = 20

[Command]
name = "DP_a"
command = ~F, D, DF, a
time = 20

[Command]
name = "DP_b"
command = ~F, D, DF, b
time = 20

[Command]
name = "RDP_a"
command = ~B, D, DB, a
time = 20

[Command]
name = "RDP_b"
command = ~B, D, DB, b
time = 20

[Command]
name = "DP_x"
command = ~F, D, DF, x
time = 20

[Command]
name = "DP_y"
command = ~F, D, DF, y
time = 20

[Command]
name = "HCF_a"
command = ~B, D, F, a
time = 15

[Command]
name = "HCF_b"
command = ~B, D, F, b
time = 15

[Command]
name = "HCF_x"
command = ~B, D, F, x
time = 15

[Command]
name = "HCF_y"
command = ~B, D, F, y
time = 15

[Command]
name = "HCB_a"
command = ~F, D, B, a
time = 15

[Command]
name = "HCB_b"
command = ~F, D, B, b
time = 15

[Command]
name = "HCB_x"
command = ~F, D, B, x
time = 15

[Command]
name = "HCB_y"
command = ~F, D, B, y
time = 15

[Command]
name = "FF_y"     ;Required (do not remove)
command = F, F, y
time = 20

[Command]
name = "FF_x"     ;Required (do not remove)
command = F, F, x
time = 20

[Command]
name = "QCF_a"
command = ~D, DF, F, a
time = 15

[Command]
name = "QCF_b"
command = ~D, DF, F, b
time = 15

[Command]
name = "QCF_x"
command = ~D, DF, F, x
time = 15

[Command]
name = "QCF_y"
command = ~D, DF, F, y
time = 15

[Command]
name = "QCB_a"
command = ~D, DB, B, a
time = 15

[Command]
name = "QCB_b"
command = ~D, DB, B, b
time = 15

[Command]
name = "QCB_x"
command = ~D, DB, B, x
time = 15

[Command]
name = "QCB_y"
command = ~D, DB, B, y
time = 15

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "PChargeA"
command = /a
time = 1

[Command]
name = "PChargeY"
command = /y
time = 1

[Command]
name = "Blowback"
command = b+y
time = 1

[Command]
name = "Roll/Dodge"
command = a+x
time = 1

[Command]
name = "ChargedDU"
command = ~13$D, $U
time = 1

[Command]
name = "hijump"
command = ~$D, $U
time = 8

[Command]
name = "recovery";Required (do not remove)
command = a+x
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdc"
command = /$c
time = 1

[Command]
name = "holdb"
command = /$b
time = 1

[Command]
name = "holda"
command = /$a
time = 1

[Command]
name = "holdz"
command = /$z
time = 1

[Command]
name = "holdy"
command = /$y
time = 1

[Command]
name = "holdx"
command = /$x
time = 1

[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact = 1
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;===============================================================================
;Supers
;-------------------------------------------------------------------------------
;V
[State -1, Ten-Ryuu Retsu-Kiba SDM]
type = ChangeState
value = 3200
triggerall = var(55) = 0
triggerall = command = "DP_z"
;triggerall = command = "z"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = fvar(5) >= 1000
trigger12 = stateno = 1000 && movecontact && statetype = S
trigger13 = fvar(5) >= 1000
trigger13 = stateno = 1005 && movecontact && statetype = S
trigger14 = fvar(5) >= 1000
trigger14 = stateno = 1325
trigger15 = fvar(5) >= 1000
trigger15 = stateno = 1425 && movecontact
trigger16 = fvar(5) >= 1000
trigger16 = stateno = 3000 && statetype = S && movecontact
trigger17 = fvar(5) >= 1000
trigger17 = stateno = 3001 && statetype = S &&  movecontact
trigger18 = fvar(5) >= 1000
trigger18 = stateno = 3100 && statetype = S &&  movecontact
trigger19 = fvar(5) >= 1000
trigger19 = stateno = 3105 && statetype = S &&  movecontact

;-------------------------------------------------------------------------------
; SDM
[State -1, Tatsu Kiba SDM]
type = ChangeState
value = 3110
triggerall = var(55) = 0
triggerall = command = "2QCF_ab"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = fvar(5) >= 1000
trigger12 = stateno = 1000 && movecontact && statetype = S
trigger13 = fvar(5) >= 1000
trigger13 = stateno = 1005 && movecontact && statetype = S
trigger14 = fvar(5) >= 1000
trigger14 = stateno = 1325
trigger15 = fvar(5) >= 1000
trigger15 = stateno = 1425 && movecontact

;-------------------------------------------------------------------------------
; 
[State -1, Tatsu Kiba DM Hard]
type = ChangeState
value = 3105
triggerall = var(55) = 0
triggerall = command = "2QCF_b"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = fvar(5) >= 1000
trigger12 = stateno = 1000 && movecontact && statetype = S
trigger13 = fvar(5) >= 1000
trigger13 = stateno = 1005 && movecontact && statetype = S
trigger14 = fvar(5) >= 1000
trigger14 = stateno = 1325
trigger15 = fvar(5) >= 1000
trigger15 = stateno = 1425 && movecontact

;-------------------------------------------------------------------------------
; 
[State -1, Tatsu Kiba DM Light]
type = ChangeState
value = 3100
triggerall = var(55) = 0
triggerall = command = "2QCF_a"
;triggerall = command = "c"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = fvar(5) >= 1000
trigger12 = stateno = 1000 && movecontact && statetype = S
trigger13 = fvar(5) >= 1000
trigger13 = stateno = 1005 && movecontact && statetype = S
trigger14 = fvar(5) >= 1000
trigger14 = stateno = 1325
trigger15 = fvar(5) >= 1000
trigger15 = stateno = 1425 && movecontact

;-------------------------------------------------------------------------------
; SDM
[State -1, Zero Kiba SDM]
type = ChangeState
value = 3050
triggerall = var(55) = 0
triggerall = command = "2QCF_xy"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = fvar(5) >= 1000
trigger12 = stateno = 1000 && movecontact && statetype = S
trigger13 = fvar(5) >= 1000
trigger13 = stateno = 1005 && movecontact && statetype = S
trigger14 = fvar(5) >= 1000
trigger14 = stateno = 1325
trigger15 = fvar(5) >= 1000
trigger15 = stateno = 1425 && movecontact

;-------------------------------------------------------------------------------
; 
[State -1, Zero Kiba DM Hard]
type = ChangeState
value = 3001
triggerall = var(55) = 0
triggerall = command = "2QCF_y"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = fvar(5) >= 1000
trigger12 = stateno = 1000 && movecontact && statetype = S
trigger13 = fvar(5) >= 1000
trigger13 = stateno = 1005 && movecontact && statetype = S
trigger14 = fvar(5) >= 1000
trigger14 = stateno = 1325
trigger15 = fvar(5) >= 1000
trigger15 = stateno = 1425 && movecontact

;-------------------------------------------------------------------------------
; 
[State -1, Zero Kiba DM Light]
type = ChangeState
value = 3000
triggerall = var(55) = 0
triggerall = command = "2QCF_x"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = fvar(5) >= 1000
trigger12 = stateno = 1000 && movecontact && statetype = S
trigger13 = fvar(5) >= 1000
trigger13 = stateno = 1005 && movecontact && statetype = S
trigger14 = fvar(5) >= 1000
trigger14 = stateno = 1325
trigger15 = fvar(5) >= 1000
trigger15 = stateno = 1425 && movecontact


;===============================================================================
;Specials
;-------------------------------------------------------------------------------
; ()
[State -1, Fuu-Ga (Hard)]
type = ChangeState
value = 1405
triggerall = var(55) = 0
triggerall = ifelse((Anim!=[5,6]),command="QCB_b",command="QCF_b")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = stateno = 1325
;-------------------------------------------------------------------------------
; ()
[State -1, Fuu-Ga (Weak)]
type = ChangeState
value = 1400
triggerall = var(55) = 0
triggerall = ifelse((Anim!=[5,6]),command="QCB_a",command="QCF_a")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = stateno = 1325
;-------------------------------------------------------------------------------
; ()
[State -1, Ura Fuu-Ga (Hard)]
type = ChangeState
value = 1305
triggerall = var(55) = 0
triggerall = var(5)=1
triggerall = ifelse((Anim!=[5,6]),command="QCB_y",command="QCF_y")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = stateno = 1325
;-------------------------------------------------------------------------------
; ()
[State -1, Ura Fuu-Ga (Weak)]
type = ChangeState
value = 1300
triggerall = var(55) = 0
triggerall = var(5)=1
triggerall = ifelse((Anim!=[5,6]),command="QCB_x",command="QCF_x")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = stateno = 1325
;-------------------------------------------------------------------------------
;EX Rӕǉ
[State -1, EX Hou-zan Sai Heki-Ga]
type = ChangeState
value = 1200
triggerall = var(55) = 0
triggerall = var(5)=2
triggerall = command = "DU_y"
;triggerall = command = "z"
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger3 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger4 = stateno = 101 || stateno = 40
trigger5 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger11 = stateno = 1325
;-------------------------------------------------------------------------------
;EX  ()
[State -1, EX Rai-Ga (Hard)]
type = ChangeState
value = 1105
triggerall = var(55) = 0
triggerall = var(5)=2
triggerall = ifelse((Anim!=[5,6]),command="DP_b",command="RDP_b")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = stateno = 1325
;-------------------------------------------------------------------------------
;EX  ()
[State -1, EX Rai-Ga (Weak)]
type = ChangeState
value = 1100
triggerall = var(55) = 0
triggerall = var(5)=2
triggerall = ifelse((Anim!=[5,6]),command="DP_a",command="RDP_a")
;triggerall = command="z"
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = stateno = 1325
;-------------------------------------------------------------------------------
;k ()
[State -1, Shin-Ga (Hard)]
type = ChangeState
value = 1005
triggerall = var(55) = 0
triggerall = ifelse((Anim!=[5,6]),command="QCF_y",command="QCB_y")
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = stateno = 1325
;-------------------------------------------------------------------------------
;k ()
[State -1, Shin-Ga (Weak)]
type = ChangeState
value = 1000
triggerall = var(55) = 0
triggerall = ifelse((Anim!=[5,6]),command="QCF_x",command="QCB_x")
;triggerall = command="c"
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger9 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
trigger11 = stateno = 980 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger12 = stateno = 1325

;===============================================================================
;-------------------------------------------------------------------------------
;n K[hLZU
[State -1, Guard Counter Blowback Attack]
type = ChangeState
value = 995
triggerall = var(55) = 0
triggerall = statetype != A
trigger1 = command = "z" || command = "Blowback"
trigger1 = stateno = 150 || stateno = 151
trigger1 = power >= 1000

;-------------------------------------------------------------------------------
; K[hLZU
[State -1, Blowback Attack Air]
type = ChangeState
value = 990
triggerall = var(55) = 0
trigger1 = command = "z" || command = "Blowback"
trigger1 = statetype = A
trigger1 = ctrl

;-------------------------------------------------------------------------------
;ӂƂ΂U
[State -1, Blowback Attack Ground]
type = ChangeState
value = 980
triggerall = var(55) = 0
trigger1 = command = "z" || command = "Blowback"
trigger1 = statetype = S
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101

;-------------------------------------------------------------------------------
;p[
[State -1, Power Charge]
type = ChangeState
value = 770
triggerall = var(55) = 0
triggerall = power < 3000
triggerall = (command = "PChargeA" && command = "PChargeY")
trigger1 = statetype != A
trigger1 = ctrl || stateno = [100,101]

;-------------------------------------------------------------------------------
;
[State -1, Dodge]
type = ChangeState
value = 765
triggerall = var(55) = 0
trigger1 = command = "Roll/Dodge"
trigger1 = command != "holdfwd" && command != "holdback"
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101

;-------------------------------------------------------------------------------
;K[hLZ]
[State -1, Emergency Evade Backward]
type = ChangeState
value = 761
triggerall = var(55) = 0
triggerall = command = "holdback"
triggerall = statetype != A
trigger1 = command = "Roll/Dodge" || command = "c"
trigger1 = stateno = 150 || stateno = 151
trigger1 = power >= 1000

;-------------------------------------------------------------------------------
;K[hLZO]
[State -1, Emergency Evade Forward]
type = ChangeState
value = 760
triggerall = var(55) = 0
triggerall = command != "holdback"
triggerall = statetype != A
trigger1 = command = "Roll/Dodge" || command = "c"
trigger1 = stateno = 150 || stateno = 151
trigger1 = power>= 1000

;-------------------------------------------------------------------------------
;]
[State -1, Roll Backward]
type = ChangeState
value = 761
triggerall = var(55) = 0
trigger1 = command = "Roll/Dodge" || command = "c"
trigger1 = command = "holdback" || command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl

;-------------------------------------------------------------------------------
;O]
[State -1, Roll Forward]
type = ChangeState
value = 760
triggerall = var(55) = 0
trigger1 = command = "Roll/Dodge" || command = "c"
trigger1 = command != "holdback"
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101

;===============================================================================
;-------------------------------------------------------------------------------
;f ()
[State -1, Grab Attempt]
type = ChangeState
value = 850
triggerall = var(55) = 0
triggerall = command = "holdfwd" || command = "holdback" && anim = 21
triggerall = command = "y" || command = "b"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = p2bodydist x < 20
trigger1 = p2movetype != H
trigger1 = p2statetype != A

;-------------------------------------------------------------------------------
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = var(55) = 0
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;-------------------------------------------------------------------------------
;obNXebv
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = var(55) = 0
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl


;===============================================================================
;-------------------------------------------------------------------------------
;R
[State -1, Mu-ran-Geri]
type = ChangeState
value = 810
triggerall = var(55) = 0
triggerall = command = "holdfwd" && command = "a" && command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger9 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact
;-------------------------------------------------------------------------------
;ӊ{
[State -1, Sai-Gaku]
type = ChangeState
value = 800
triggerall = var(55) = 0
triggerall = command = "holdfwd" && command = "x" && command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && animelemtime(3) > 0 && animelemtime(4) < 0
trigger3 = stateno = 201 && animelemtime(2) > 0 && animelemtime(3) < 0
trigger4 = stateno = 211 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger5 = stateno = 231 && animelemtime(4) > 0 && animelemtime(5) < 0
trigger6 = stateno = 241 && animelemtime(2) > 0 && animelemtime(5) < 0
trigger7 = stateno = 400 && animelemtime(3) > 1 && animelemtime(4) < 0
trigger8 = stateno = 430 && animelemtime(3) > 1 && animelemtime(5) < 0
trigger9 = stateno = 410 && animelemtime(4) > 1 && animelemtime(5) < 0
trigger10 = stateno = 440 && animelemtime(5) > 1 && animelemtime(6) < 0 && !movecontact

;-------------------------------------------------------------------------------
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = var(55) = 0
triggerall = command = "start"
trigger1 = stateno != 195
trigger1 = statetype != A
trigger1 = ctrl

;-------------------------------------------------------------------------------
; p`
[State -1, Long Stand A]
type = ChangeState
value = 200
triggerall = var(55) = 0
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = p2bodydist x > 25
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && time > 8
trigger3 = stateno = 201 && time > 4
trigger3 = stateno = 400 && time > 8
trigger4 = stateno = 430 && time > 9

;-------------------------------------------------------------------------------
;ߋ p`
[State -1, Short Stand A]
type = ChangeState
value = 201
triggerall = var(55) = 0
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = p2bodydist x <= 25
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && time > 8
trigger3 = stateno = 201 && time > 4
trigger3 = stateno = 400 && time > 8
trigger4 = stateno = 430 && time > 9

;-------------------------------------------------------------------------------
; p`
[State -1, Long Stand C]
type = ChangeState
value = 210
triggerall = var(55) = 0
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = p2bodydist x > 25
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101

;-------------------------------------------------------------------------------
;ߋ p`
[State -1, Short Stand C]
type = ChangeState
value = 211
triggerall = var(55) = 0
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = p2bodydist x <= 25
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101

;-------------------------------------------------------------------------------
; LbN
[State -1, Long Stand B]
type = ChangeState
value = 230
triggerall = var(55) = 0
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = p2bodydist x > 35
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && time > 8
trigger3 = stateno = 201 && time > 4
trigger3 = stateno = 400 && time > 8
trigger4 = stateno = 430 && time > 9

;-------------------------------------------------------------------------------
;ߋ LbN
[State -1, Short Stand B]
type = ChangeState
value = 231
triggerall = var(55) = 0
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = p2bodydist x <= 35
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger2 = stateno = 200 && time > 8
trigger3 = stateno = 201 && time > 4
trigger3 = stateno = 400 && time > 8
trigger4 = stateno = 430 && time > 9

;-------------------------------------------------------------------------------
; LbN
[State -1, Long Stand D]
type = ChangeState
value = 240
triggerall = var(55) = 0
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = p2bodydist x > 25
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101

;-------------------------------------------------------------------------------
;ߋ LbN
[State -1, Short Stand D]
type = ChangeState
value = 241
triggerall = var(55) = 0
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = p2bodydist x <= 25
trigger1 = statetype != A
trigger1 = ctrl || (stateno = 100 && animelemtime(2) >1) || stateno = 101

;-------------------------------------------------------------------------------
;Ⴊݎp`
[State -1, Crouching A]
type = ChangeState
value = 400
triggerall = var(55) = 0
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger3 = stateno = 200 && time > 8
trigger4 = stateno = 201 && time > 4
trigger5 = stateno = 400 && time > 8
trigger6 = stateno = 430 && time > 9

;-------------------------------------------------------------------------------
;Ⴊ݋p`
[State -1, Crouching C]
type = ChangeState
value = 410
triggerall = var(55) = 0
triggerall = command = "holddown"
triggerall = command = "y"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 100 && animelemtime(2) >1) || stateno = 101

;-------------------------------------------------------------------------------
;ႪݎLbN
[State -1, Crouching B]
type = ChangeState
value = 430
triggerall = var(55) = 0
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 100 && animelemtime(2) >1) || stateno = 101
trigger3 = stateno = 200 && time > 8
trigger4 = stateno = 201 && time > 4
trigger5 = stateno = 400 && time > 8
trigger6 = stateno = 430 && time > 9

;-------------------------------------------------------------------------------
;Ⴊ݋LbN
[State -1, Crouching D]
type = ChangeState
value = 440
triggerall = var(55) = 0
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 100 && animelemtime(2) >1) || stateno = 101

;-------------------------------------------------------------------------------
; p`
[State -1, Jump A]
type = ChangeState
value = 600
triggerall = var(55) = 0
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

;-------------------------------------------------------------------------------
; p`
[State -1, Jump C]
type = ChangeState
value = 610
triggerall = var(55) = 0
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl

;-------------------------------------------------------------------------------
; LbN
[State -1, Jump B]
type = ChangeState
value = 630
triggerall = var(55) = 0
triggerall = command = "a"
;trigger1 = vel x = 0
trigger1 = statetype = A
trigger1 = ctrl

;-------------------------------------------------------------------------------
; LbN
[State -1, Jump D]
type = ChangeState
value = 640
triggerall = var(55) = 0
triggerall = command = "b"
;trigger1 = vel x = 0
trigger1 = statetype = A
trigger1 = ctrl

;-------------------------------------------------------------------------------
;Jump Light Kick Vel X != 0
[State -1, Jump Light Kick Vel X != 0]
type = Null
value = 631
triggerall = var(55) = 0
triggerall = command = "a"
trigger1 = vel x != 0
trigger1 = statetype = A
trigger1 = ctrl

;-------------------------------------------------------------------------------
;Jump Strong Kick Vel X != 0
[State -1, Jump Strong Kick Vel X!= 0]
type = Null
value = 641
triggerall = var(55) = 0
triggerall = command = "b"
trigger1 = vel x != 0
trigger1 = statetype = A
trigger1 = ctrl



